@@ -42,6 +42,7 @@ import octobot.constants as constants
 import octobot.disclaimer as disclaimer
 import octobot.logger as octobot_logger
 import octobot.community as octobot_community
+import octobot.limits as limits
 
 
 def update_config_with_args(starting_args, config: configuration.Configuration, logger):
@@ -192,6 +193,7 @@ def start_octobot(args):
             return
 
         logger = octobot_logger.init_logger()
+        startup_messages = []
 
         # Version
         logger.info("Version : {0}".format(constants.LONG_VERSION))
@@ -231,6 +233,9 @@ def start_octobot(args):
         # Keep track of errors if any
         octobot_community.register_error_uploader(constants.ERRORS_POST_ENDPOINT, config)
 
+        # Apply config limits if any
+        startup_messages += limits.apply_config_limits(config)
+
         # create OctoBot instance
         if args.backtesting:
             bot = octobot_backtesting.OctoBotBacktestingFactory(config,
@@ -238,7 +243,8 @@ def start_octobot(args):
                                                                 enable_join_timeout=args.enable_backtesting_timeout,
                                                                 enable_logs=not args.no_logs)
         else:
-            bot = octobot_class.OctoBot(config, reset_trading_history=args.reset_trading_history)
+            bot = octobot_class.OctoBot(config, reset_trading_history=args.reset_trading_history,
+                                        startup_messages=startup_messages)
 
         # set global bot instance
         octobot.set_bot(bot)
